==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/ru_RU.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Не все календари полностью кэшированы",
"No calendars found." => "Не найдено календарей",
"No events found." => "Не найдено событий",
"Wrong calendar" => "Неверный календарь",
"The file contained either no events or all events are already saved in your calendar." => "Файл либо не содержит событий, либо все события уже сохранены в Вашем календаре.",
"events has been saved in the new calendar" => "Событие было сохранено в новом календаре ",
"Import failed" => "Импортирование не удалось",
"events has been saved in your calendar" => "Событие было сохранено в Вашем календаре ",
"New Timezone:" => "Новый часовой пояс",
"Timezone changed" => "Часовой пояс изменен",
"Invalid request" => "Неверный запрос",
"Calendar" => "Календарь",
"Deletion failed" => "Удаление не удалось",
"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "ддд д ММММ[ гггг]{ -[ддд д] ММММ гггг}",
"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "ддд д ММММ[ гггг] чч:мм{ -[ ддд д ММММ гггг] чч:мм}",
"user" => "пользователь",
"group" => "группа",
"Editable" => "Редактируемо",
"Shareable" => "Совместный ",
"ddd" => "ддд",
"ddd M/d" => "ддд М/д",
"dddd M/d" => "дддд М/д",
"MMMM yyyy" => "ММММ гггг",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "МММ д[ гггг]{ '&#8212;'[ МММ] д гггг}",
"dddd, MMM d, yyyy" => "дд, мм, гггг",
"Birthday" => "День Рождения",
"Business" => "Рабочий",
"Call" => "Звонок",
"Clients" => "Клиенты",
"Deliverer" => "Поставщик",
"Holidays" => "Праздники",
"Ideas" => "Идеи",
"Journey" => "Путешествие",
"Jubilee" => "Юбилей",
"Meeting" => "Встреча",
"Other" => "Другое",
"Personal" => "Персональный",
"Projects" => "Проекты",
"Questions" => "Вопросы",
"Work" => "Работа",
"unnamed" => "безымянный",
"You do not have the permissions to update this calendar." => "У Вас нет прав доступа для обновление этого календаря.",
"You do not have the permissions to delete this calendar." => "У Вас нет прав доступа для удаления этого календаря.",
"You do not have the permissions to add to this calendar." => "У Вас нет прав доступа для добавления этого календаря.",
"New Calendar" => "Новый календарь",
"You do not have the permissions to add events to this calendar." => "У Вас нет прав доступа для добавления событий в этот календарь.",
"You do not have the permissions to edit this event." => "У Вас нет прав доступа для редактирования этого события.",
"You do not have the permissions to delete this event." => "У Вас нет прав доступа для удаления этого события.",
"Does not repeat" => "Не повторяется",
"Daily" => "Ежедневный",
"Weekly" => "Еженедельный",
"Every Weekday" => "Каждый будний день",
"Bi-Weekly" => " Раз в две недели",
"Monthly" => "Ежемесячно",
"Yearly" => "Ежегодно",
"never" => "никогда",
"by date" => "по дате",
"Monday" => "Понедельник",
"Tuesday" => "Вторник",
"Wednesday" => "Среда",
"Thursday" => "Четверг",
"Friday" => "Пятница",
"Saturday" => "Суббота",
"Sunday" => "Воскресенье",
"first" => "первый",
"second" => "второй",
"third" => "третий",
"fourth" => "четвертый",
"fifth" => "пятый",
"last" => "последний",
"January" => "Январь",
"February" => "Февраль",
"March" => "Март",
"April" => "Апрель",
"May" => "Май",
"June" => "Июнь",
"July" => "Июль",
"August" => "Август",
"September" => "Сентябрь",
"October" => "Октябрь",
"November" => "Ноябрь",
"December" => "Декабрь",
"Date" => "Дата",
"Cal." => "Календарь",
"Sun." => "Воскр.",
"Mon." => "Пон.",
"Tue." => "Вт.",
"Wed." => "Ср.",
"Thu." => "Четв.",
"Fri." => "Пятн.",
"Sat." => "Субб.",
"Jan." => "Янв.",
"Feb." => "Февр.",
"Mar." => "Март",
"Apr." => "Апр.",
"May." => "Май",
"Jun." => "Июнь",
"Jul." => "Июль",
"Aug." => "Авг.",
"Sep." => "Сент.",
"Oct." => "Окт.",
"Nov." => "Нояб.",
"Dec." => "Дек.",
"All day" => "Весь день",
"Missing fields" => "Отсутствующие поля",
"Title" => "Название",
"From Date" => "С (дата)",
"From Time" => "С (время)",
"To Date" => "По (дата)",
"To Time" => "По (время)",
"The event ends before it starts" => "Событие заканчивается прежде, чем началось",
"There was a database fail" => "Произошел сбой базы данных",
"Week" => "Неделя",
"Month" => "Месяц",
"List" => "Список",
"Today" => "Сегодня",
"Calendars" => "Календари",
"Settings" => "Настройки",
"Your calendars" => "Ваши календари",
"CalDav Link" => "CalDav ссылка",
"Share Calendar" => "Сделать календарь общим",
"Download" => "Загрузка",
"Edit" => "Редактировать",
"Delete" => "Удалить",
"New calendar" => "Новый календарь",
"Edit calendar" => "Редактировать календарь",
"Displayname" => "Отображаемое имя",
"Active" => "Активный",
"Calendar color" => "Цвет календаря",
"Save" => "Сохранить",
"Submit" => "Отправить",
"Cancel" => "Отмена",
"Edit an event" => "Редактировать событие",
"Export" => "Экспорт",
"Repeating" => "Повторяющийся",
"Share" => "Сделать общим",
"Title of the Event" => "Название события",
"Category" => "Категория",
"All Day Event" => "Событие на весь день",
"From" => "От",
"To" => "До",
"Advanced options" => "Дополнительные опции",
"Location" => "Местоположение",
"Location of the Event" => "Местоположение события",
"Description" => "Описание",
"Description of the Event" => "Описание события",
"Repeat" => "Повтор",
"Select weekdays" => "Выбрать дни недели",
"Select days" => "Выбрать дни",
"Select months" => "Выбрать месяцы",
"Select weeks" => "Выбрать недели",
"Interval" => "Интервал",
"End" => "Конец",
"create a new calendar" => "создать новый календарь",
"Import a calendar file" => "Импортировать файл календаря",
"Please choose a calendar" => "Пожалуйста, выберите календарь.",
"Name of new calendar" => "Имя нового календаря",
"Take an available name!" => "Возьмите доступное имя!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Календарь с таким именем  существует. Если вы будете продолжать так или иначе, эти календари будут объединены.",
"Import" => "Импорт",
"Close Dialog" => "Закрыть диалог",
"Create a new event" => "Создать новое событие",
"Share with:" => "Сделать общий доступ с:",
"Shared with" => "Общий доступ с",
"Unshare" => "Отключить общий доступ",
"Nobody" => "Никто",
"Shared via calendar" => "Сделать общим посредством календаря",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "ПРИМЕЧАНИЕ: Действия с событиями, введенными в общий доступ посредством календаря, будут оказывать влияние на весь календарный обмен.",
"View an event" => "Просмотр события",
"No categories selected" => "Не выбрано категорий",
"General" => "Общие",
"Timezone" => "Часовой пояс",
"Update timezone automatically" => "Автоматически обновлять часовой пояс",
"Time format" => "Формат времени",
"24h" => "24ч",
"12h" => "12ч",
"Start week on" => "Начать неделю с",
"Cache" => "Кэш",
"Clear cache for repeating events" => "Очистить кэш для повторяющихся событий",
"URLs" => "URLs",
"more info" => "подробная информация",
"iOS/OS X" => "iOS/OS X"
);

==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/ru_RU.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Не все календари полностью кэшированы",
"Everything seems to be completely cached" => "Все кажется полностью записанным в кэш",
"No calendars found." => "Не найдено календарей",
"No events found." => "Не найдено событий",
"Wrong calendar" => "Неверный календарь",
"You do not have the permissions to edit this event." => "У Вас нет прав доступа для редактирования этого события.",
"The file contained either no events or all events are already saved in your calendar." => "Файл либо не содержит событий, либо все события уже сохранены в Вашем календаре.",
"events has been saved in the new calendar" => "Событие было сохранено в новом календаре ",
"Import failed" => "Импортирование не удалось",
"events has been saved in your calendar" => "Событие было сохранено в Вашем календаре ",
"New Timezone:" => "Новый часовой пояс:",
"Timezone changed" => "Часовой пояс изменен",
"Invalid request" => "Неверный запрос",
"Calendar" => "Календарь",
"Deletion failed" => "Удаление не удалось",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "пользователь",
"group" => "группа",
"Editable" => "Редактируемо",
"Shareable" => "Совместный ",
"Deletable" => "Удаляемый",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Воскресенье",
"Monday" => "Понедельник",
"Tuesday" => "Вторник",
"Wednesday" => "Среда",
"Thursday" => "Четверг",
"Friday" => "Пятница",
"Saturday" => "Суббота",
"Sun." => "Воскр.",
"Mon." => "Пон.",
"Tue." => "Вт.",
"Wed." => "Ср.",
"Thu." => "Четв.",
"Fri." => "Пятн.",
"Sat." => "Субб.",
"January" => "Январь",
"February" => "Февраль",
"March" => "Март",
"April" => "Апрель",
"May" => "Май",
"June" => "Июнь",
"July" => "Июль",
"August" => "Август",
"September" => "Сентябрь",
"October" => "Октябрь",
"November" => "Ноябрь",
"December" => "Декабрь",
"Jan." => "Янв.",
"Feb." => "Февр.",
"Mar." => "Март",
"Apr." => "Апр.",
"May." => "Май",
"Jun." => "Июнь",
"Jul." => "Июль",
"Aug." => "Авг.",
"Sep." => "Сент.",
"Oct." => "Окт.",
"Nov." => "Нояб.",
"Dec." => "Дек.",
"All day" => "Весь день",
"New Calendar" => "Новый календарь",
"Missing or invalid fields" => "Пропущенные или недопустимые поля",
"Title" => "Название",
"From Date" => "С (дата)",
"From Time" => "С (время)",
"To Date" => "По (дата)",
"To Time" => "По (время)",
"The event ends before it starts" => "Событие заканчивается прежде, чем началось",
"There was a database fail" => "Произошел сбой базы данных",
"Birthday" => "День Рождения",
"Business" => "Рабочий",
"Call" => "Звонок",
"Clients" => "Клиенты",
"Deliverer" => "Поставщик",
"Holidays" => "Праздники",
"Ideas" => "Идеи",
"Journey" => "Путешествие",
"Jubilee" => "Юбилей",
"Meeting" => "Встреча",
"Other" => "Другое",
"Personal" => "Персональный",
"Projects" => "Проекты",
"Questions" => "Вопросы",
"Work" => "Работа",
"by" => " ",
"unnamed" => "безымянный",
"You do not have the permissions to update this calendar." => "У Вас нет прав доступа для обновление этого календаря.",
"You do not have the permissions to delete this calendar." => "У Вас нет прав доступа для удаления этого календаря.",
"You do not have the permissions to add to this calendar." => "У Вас нет прав доступа для добавления этого календаря.",
"You do not have the permissions to add events to this calendar." => "У Вас нет прав доступа для добавления событий в этот календарь.",
"You do not have the permissions to delete this event." => "У Вас нет прав доступа для удаления этого события.",
"Busy" => "Занятый",
"Public" => "Публичный",
"Private" => "Частный",
"Confidential" => "Конфиденциальный",
"Does not repeat" => "Не повторяется",
"Daily" => "Ежедневный",
"Weekly" => "Еженедельный",
"Every Weekday" => "Каждый будний день",
"Bi-Weekly" => " Раз в две недели",
"Monthly" => "Ежемесячно",
"Yearly" => "Ежегодно",
"never" => "никогда",
"by occurrences" => "по распространенности",
"by date" => "по дате",
"by monthday" => "по дню месяца",
"by weekday" => "по будням",
"events week of month" => "события недели месяца",
"first" => "первый",
"second" => "второй",
"third" => "третий",
"fourth" => "четвертый",
"fifth" => "пятый",
"last" => "последний",
"by events date" => "по дате событий",
"by yearday(s)" => "по дням года",
"by weeknumber(s)" => "по номеру недели",
"by day and month" => "по дню и месяцу",
"Date" => "Дата",
"Cal." => "Календарь",
"Week" => "Неделя",
"Month" => "Месяц",
"List" => "Список",
"Today" => "Сегодня",
"Settings" => "Настройки",
"Your calendars" => "Ваши календари",
"CalDav Link" => "CalDav ссылка",
"Share Calendar" => "Сделать календарь общим",
"Download" => "Загрузка",
"Edit" => "Редактировать",
"Delete" => "Удалить",
"New calendar" => "Новый календарь",
"Edit calendar" => "Редактировать календарь",
"Displayname" => "Отображаемое имя",
"Active" => "Активный",
"Calendar color" => "Цвет календаря",
"Save" => "Сохранить",
"Submit" => "Принять",
"Cancel" => "Отмена",
"Edit an event" => "Редактировать событие",
"Export" => "Экспорт",
"Eventinfo" => "Информация о событии",
"Repeating" => "Повтор",
"Alarm" => "Сигнал",
"Attendees" => "Участники",
"Share" => "Сделать общим",
"Title of the Event" => "Название события",
"Category" => "Категория",
"Separate categories with commas" => "Отдельные категории, разделенные запятыми",
"Edit categories" => "Редактировать категории",
"Access Class" => "Класс доступа",
"All Day Event" => "Событие на весь день",
"From" => "От",
"To" => "До",
"Advanced options" => "Дополнительные опции",
"Location" => "Местоположение",
"Location of the Event" => "Местоположение события",
"Description" => "Описание",
"Description of the Event" => "Описание события",
"Repeat" => "Повтор",
"Advanced" => "Расширенный",
"Select weekdays" => "Выбрать дни недели",
"Select days" => "Выбрать дни",
"and the events day of year." => "и день года события",
"and the events day of month." => "и день месяца события",
"Select months" => "Выбрать месяцы",
"Select weeks" => "Выбрать недели",
"and the events week of year." => "и неделя года события",
"Interval" => "Интервал",
"End" => "Конец",
"occurrences" => "распространенность",
"create a new calendar" => "создать новый календарь",
"Import a calendar file" => "Импортировать файл календаря",
"Please choose a calendar" => "Пожалуйста, выберите календарь.",
"Name of new calendar" => "Имя нового календаря",
"Take an available name!" => "Возьмите доступное имя!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Календарь с таким именем  существует. Если вы будете продолжать так или иначе, эти календари будут объединены.",
"Remove all events from the selected calendar" => "Удалить все события из выбранного календаря",
"Import" => "Импорт",
"Close Dialog" => "Закрыть диалог",
"Create a new event" => "Создать новое событие",
"Share with:" => "Сделать общий доступ с:",
"Shared with" => "Общий доступ с",
"Unshare" => "Отключить общий доступ",
"Nobody" => "Никто",
"Shared via calendar" => "Сделать общим посредством календаря",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "ПРИМЕЧАНИЕ: Действия с событиями, введенными в общий доступ посредством календаря, будут оказывать влияние на весь календарный обмен.",
"View an event" => "Просмотр события",
"No categories selected" => "Не выбрано категорий",
"of" => " ",
"at" => "на",
"General" => "Общие",
"Timezone" => "Часовой пояс",
"Update timezone automatically" => "Автоматически обновлять часовой пояс",
"Time format" => "Формат времени",
"24h" => "24ч",
"12h" => "12ч",
"Start week on" => "Начать неделю с",
"Cache" => "Кэш",
"Clear cache for repeating events" => "Очистить кэш для повторяющихся событий",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Адреса синхронизации CalDAV календаря",
"more info" => "подробная информация",
"Primary address (Kontact et al)" => "Основной адрес (Kontact и др.)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "iCalendar-cсылки только для чтения "
);
